# KiCad Plugin Rules

**NEVER read, edit, or write KiCad files directly.** This includes `.kicad_sch`, `.kicad_pcb`, `.kicad_sym`, `.kicad_mod`, and `.kicad_pro` files. Do NOT use the Read, Write, or Edit tools on these files. ALL KiCad file manipulation MUST go through the MCP tools provided by the `kicad` server.

**NEVER run kicad-cli commands directly.** Use the export, ERC, and DRC tools provided by the kicad MCP server.

When a KiCad MCP tool returns an error, try different parameters or a different tool. Do NOT fall back to manual file editing.
